searchData={"content_type":"text/markdown","items":[{"doc":"A module to decode html into a tree structure.","ref":":fast_html.html","title":":fast_html","type":"module"},{"doc":"Returns a tree representation from the given html string.\n\n`opts` is a keyword list of options, the options available:\n* `timeout` - Call timeout. If pooling is used and the worker doesn't return\n   the result in time, the worker will be killed with a warning.\n* `format` - Format flags for the tree.\n\nThe following format flags are available:\n\n* `:html_atoms` uses atoms for known html tags (faster), binaries for everything else.\n* `:nil_self_closing` uses `nil` to designate void elements.\n    For example ` ` is then being represented like `{\"br\", [], nil}`.\n    See http://w3c.github.io/html-reference/syntax.html#void-elements for a full list of void elements.\n* `:comment_tuple3` uses 3-tuple elements for comments, instead of the default 2-tuple element.","ref":":fast_html.html#decode/2","title":":fast_html.decode/2","type":"function"},{"doc":"iex> :fast_html.decode(\" Hello world \")\n    {:ok, [{\"html\", [], [{\"head\", [], []}, {\"body\", [], [{\"h1\", [], [\"Hello world\"]}]}]}]}\n\n    iex> :fast_html.decode(\"Hello world\", timeout: 0)\n    {:error, :timeout}\n\n    iex> :fast_html.decode(\" Hi there \")\n    {:ok, [{\"html\", [],\n     [{\"head\", [], []},\n      {\"body\", [], [{\"span\", [{\"class\", \"hello\"}], [\"Hi there\"]}]}]}]}\n\n    iex> :fast_html.decode(\" <!-- a comment --!> \")\n    {:ok, [{\"html\", [], [{\"head\", [], []}, {\"body\", [], [comment: \" a comment \"]}]}]}\n\n    iex> :fast_html.decode(\" \")\n    {:ok, [{\"html\", [], [{\"head\", [], []}, {\"body\", [], [{\"br\", [], []}]}]}]}\n\n    iex> :fast_html.decode(\" Hello world \", format: [:html_atoms])\n    {:ok, [{:html, [], [{:head, [], []}, {:body, [], [{:h1, [], [\"Hello world\"]}]}]}]}\n\n    iex> :fast_html.decode(\" \", format: [:nil_self_closing])\n    {:ok, [{\"html\", [], [{\"head\", [], []}, {\"body\", [], [{\"br\", [], nil}]}]}]}\n\n    iex> :fast_html.decode(\" <!-- a comment --!> \", format: [:comment_tuple3])\n    {:ok, [{\"html\", [], [{\"head\", [], []}, {\"body\", [], [{:comment, [], \" a comment \"}]}]}]}\n\n    iex> html = \" <!-- a comment --!>  \"\n    iex> :fast_html.decode(html, format: [:html_atoms, :nil_self_closing, :comment_tuple3])\n    {:ok, [{:html, [],\n     [{:head, [], []},\n      {:body, [], [{:comment, [], \" a comment \"}, {\"unknown\", [], []}]}]}]}","ref":":fast_html.html#decode/2-examples","title":"Examples - :fast_html.decode/2","type":"function"},{"doc":"Like `decode/2`, but for parsing [HTML fragments](https://html.spec.whatwg.org/multipage/parsing.html#parsing-html-fragments).\n\n`opts` is a keyword list of options, the options available are the same as in `decode/2` with addition of:\n* `context` - Name of the context element, defaults to `div`\n\nExample:\n    iex> :fast_html.decode_fragment(\"rin is the  best  girl\")\n    {:ok, [\"rin is the \", {\"i\", [], [\"best\"]}, \" girl\"]}\n    iex> :fast_html.decode_fragment(\"rin is the  best  girl\", context: \"title\")\n    {:ok, [\"rin is the  best  girl\"]}\n    iex> :fast_html.decode_fragment(\"rin is the  best  girl\", context: \"objective_truth\")\n    {:error, :unknown_context_tag}\n    iex> :fast_html.decode_fragment(\"rin is the  best  girl\", format: [:html_atoms])\n    {:ok, [\"rin is the \", {:i, [], [\"best\"]}, \" girl\"]}","ref":":fast_html.html#decode_fragment/2","title":":fast_html.decode_fragment/2","type":"function"},{"doc":"","ref":":fast_html.html#open_port/0","title":":fast_html.open_port/0","type":"function"},{"doc":"","ref":":fast_html.html#t:attr/0","title":":fast_html.attr/0","type":"type"},{"doc":"","ref":":fast_html.html#t:attr_list/0","title":":fast_html.attr_list/0","type":"type"},{"doc":"","ref":":fast_html.html#t:comment_node3/0","title":":fast_html.comment_node3/0","type":"type"},{"doc":"","ref":":fast_html.html#t:comment_node/0","title":":fast_html.comment_node/0","type":"type"},{"doc":"","ref":":fast_html.html#t:format_flag/0","title":":fast_html.format_flag/0","type":"type"},{"doc":"","ref":":fast_html.html#t:tag/0","title":":fast_html.tag/0","type":"type"},{"doc":"","ref":":fast_html.html#t:tree/0","title":":fast_html.tree/0","type":"type"},{"doc":"","ref":"FastHtml.Pool.html","title":"FastHtml.Pool","type":"module"},{"doc":"","ref":"FastHtml.Pool.html#get_port/2","title":"FastHtml.Pool.get_port/2","type":"function"},{"doc":"Starts the port pool.\n\n#","ref":"FastHtml.Pool.html#start_link/1","title":"FastHtml.Pool.start_link/1","type":"function"},{"doc":"- `:size` - Number of ports in the pool. Defaults to `System.schedulers_online/0` if not set.\n- `:name` - Registered name of the pool. Defaults to `Elixir.FastHtml.Pool` if not set, set to `false` to not register the process.","ref":"FastHtml.Pool.html#start_link/1-options","title":"Options - FastHtml.Pool.start_link/1","type":"function"},{"doc":"","ref":"FastHtml.Pool.html#t:option/0","title":"FastHtml.Pool.option/0","type":"type"},{"doc":"","ref":"FastHtml.Pool.html#t:pool/0","title":"FastHtml.Pool.pool/0","type":"type"},{"doc":"","ref":"FastHtml.Pool.html#t:result/0","title":"FastHtml.Pool.result/0","type":"type"},{"doc":"<!--\nSPDX-FileCopyrightText: 2017-2019 myhtmlex authors  \nSPDX-FileCopyrightText: 2019-2022 Pleroma Authors  \nSPDX-License-Identifier: LGPL-2.1-only\n-->\n\n# FastHTML\n\nA C Node wrapping [lexbor](https://github.com/lexbor/lexbor).\nPrimarily used with [FastSanitize](https://git.pleroma.social/pleroma/fast_sanitize).\n\n* Available as a hex package: `{:fast_html, \"~> 2.0\"}`\n* [Documentation](https://hexdocs.pm/fast_html/fast_html.html)","ref":"readme.html","title":"FastHTML","type":"extras"},{"doc":"- GNU Make\n- C Compiler\n- Erlang 22.0+ with development headers\n- (optional) [lexbor](https://github.com/lexbor/lexbor) 2.2.0+\n\nIf you want to use a system installation of lexbor, you can set `WITH_SYSTEM_LEXBOR=1` during compilation time. By default it will used the vendored version present at `c_src/lexbor`.","ref":"readme.html#compiling","title":"Compiling - FastHTML","type":"extras"},{"doc":"The following table provides median times it takes to decode a string to a tree for html parsers that can be used from Elixir. Benchmarks were conducted on a machine with an `AMD Ryzen 9 3950X (32) @ 3.500GHz` CPU and 32GB of RAM. The `mix fast_html.bench` task can be used for running the benchmark by yourself.\n\n| File/Parser          | fast_html (Port) | mochiweb_html (erlang) | html5ever (Rust NIF) | Myhtmlex (NIF)¹ |\n|----------------------|--------------------|------------------------|----------------------|----------------|\n| document-large.html (6.9M)  | 125.12 ms          | 1778.34 ms             | 395.21 ms            | 327.17 ms      |\n| document-small.html  (25K)| 0.50 ms            | 2.76 ms                | 1.72 ms              | 1.19 ms        |\n| fragment-large.html  (33K)| 0.93 ms            | 4.78 ms               | 2.34 ms              | 2.15 ms        |\n| fragment-small.html²  (757B)| 44.60 μs | 42.13 μs | 43.58 μs | 289.71 μs |\n\nFull benchmark output can be seen in [this snippet](https://git.pleroma.social/pleroma/elixir-libraries/fast_html/snippets/3128)\n\n1. Myhtmlex has a C-Node mode, but it wasn't benchmarked here because it segfaults on `document-large.html`\n2. The slowdown on `fragment-small.html` is due to Port overhead. Unlike html5ever and Myhtmlex in NIF mode, `fast_html` has the parser process isolated and communicates with it over stdio, so even if a fatal crash in the parser happens, it won't bring down the entire VM.","ref":"readme.html#benchmarks","title":"Benchmarks - FastHTML","type":"extras"},{"doc":"* Please make sure you do `git submodule update` after a checkout/pull\n* The project aims to be fully tested","ref":"readme.html#contribution-bug-reports","title":"Contribution / Bug Reports - FastHTML","type":"extras"},{"doc":"<!--\nSPDX-FileCopyrightText: 2019-2022 Pleroma Authors  \nSPDX-License-Identifier: LGPL-2.1-only\n-->\n\n# Changelog\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).\n\n## [2.3.0] - 2023-08-18","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"- Ability to use system lexbor","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Remove compatibility for Erlang <22","ref":"changelog.html#removed","title":"Removed - Changelog","type":"extras"},{"doc":"- Allow custom CFLAGS\n- Updated vendored lexbor to 2.3.0\n\n## [2.2.0] - 2023-04-08\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Updated vendored lexbor to 2.2.0\n\n## [2.0.4] - 2020-09-01\n##","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Regression of the gcc 10 fix in the hex package, due to an outdated submodule on the publishing machine\n\n## [2.0.3] - 2020-08-30\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Improved error message on make errors\n\n## [2.0.2] - 2020-08-26\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- lexbor compilation errors with gcc 10\n- Inability to use the library with distillery releases due to priv dir being in the source code\n\n## [2.0.1] - 2020-08-04\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Build failures using the hex package due to CMake cache files accidentally included there\n\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Changelog is now available at hexdocs\n\n\n## [2.0.0] - 2020-08-01\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- **Breaking:** CMake is now required at compile-time due to it being lexbor's build system\n- **Breaking:** namespaces are no longer automatically appended. i.e `   ` will be `{\"svg\", [], []}` instead of `{\"svg:svg\", [], []}`\n- **Breaking:** when using `:nil_self_closing` flag, only valid [void elements](https://html.spec.whatwg.org/#void-elements) will have `nil` in children\n- Now deprecated myhtml was switched to [lexbor](https://github.com/lexbor/lexbor)\n- The worker process now communicates with the node via stdio, instead of TCP, which was known to cause issues\non BSD systems \n\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- `FastHtml.Pool` for fast_html workers. There is a default pool of `System.schedulers_online/0` workers, but a custom pool can be started if desired, or it can be disabled altogether. See `FastHtml.Pool` module documentation for more info\n\n## [1.0.3] - 2020-02-10\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- C-Node not respawning after being killed.\n\n## [1.0.2] - 2020-02-10\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Incorrect behavior when parsing empty attribute values. Instead of an empty string the attribute name was returned.\n\n## [1.0.1] - 2019-12-11\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- `:fast_html.decode_fragment`\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Errors from C-Node not being reported, timing out instead\n\n## [1.0.0] - 2019-12-02\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- **BREAKING:** `:fast_html.decode` now returns an array of nodes at the top level, instead of a single node. This was done because it's possible to have more than one root node, for example in (`<!-- a comment -->    ` both the comment and the `html` tag are root nodes).\n\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Worker going into infinite loop when decoding a document with more than one root node.","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"}]}